Learn R Programming

R2WinBUGS (version 0.2-7)

bugs.data: Writing input for WinBUGS

Description

Write file data.txt for WinBUGS to read.

Usage

bugs.data(data, dir = getwd(), digits = 5)

Arguments

data
either a named list (names corresponding to variable names in the model.file) of the data for the WinBUGS model, or a vector or list of the names of the data objects used by the model
dir
the directory to write the file data.txt to
digits
number of significant digits used for WinBUGS input, see formatC

Value

  • Does not return anything.

See Also

bugs