Learn R Programming

R2WinBUGS (version 0.2-7)

bugs.inits: Writing input for WinBUGS - intended for internal use only

Description

Write files inits1.txt, inits2.txt, etc., in the working directory for WinBUGS to read. For internal use only.

Usage

bugs.inits(inits, n.chains, digits)

Arguments

inits
a list with n.chains elements; each element of the list is itself a list of starting values for the WinBUGS model, or a function creating (possibly random) initial values
n.chains
number of Markov chains
digits
number of significant digits used for WinBUGS input, see formatC

Value

  • Does not return anything.

See Also

The main function to be called by the user is bugs.