display parallel intervals in both halves of the summary plots;
this is a convergence-monitoring tool and is not necessary once you have approximate convergence
(default is FALSE)
...
further arguments to be passed to low-level plot functions
Value
Does not return anything, but prints and plots as side-effects.
Details
bugs.plot.summary (left hand side of plot) and bugs.plot.inferences (right hand side of plot).
See Also
The main function to be called by the user is plot, see plot.bugs for details.