Learn R Programming

R2WinBUGS (version 0.2-7)

bugs.script: Writes script for running WinBUGS - intended for internal use only

Description

Write file script.txt for WinBUGS to read - intended for internal use only

Usage

bugs.script(parameters.to.save, n.chains, n.iter, n.burnin, n.thin, 
    bugs.directory, model.file, debug = FALSE, is.inits, bin)

Arguments

parameters.to.save
parameters that should be monitored
n.chains
number of Markov chains
n.iter
number of total iterations (including burn in)
n.burnin
length of burn in
n.thin
size of thinning parameter
bugs.directory
directory that contains the WinBUGS executable
model.file
file containing the model written in WinBUGS code
debug
if FALSE, WinBUGS is closed automatically, otherwise WinBUGS remains open for further investigation
is.inits
logical; whether initial values are given by the user (TRUE) or have to be generated by WinBUGS
bin
number of iterations between saving of results

Value

  • Does not return anything.

See Also

The main function to be called by the user is bugs.