monitor(a, n.chains, trans = NULL, keep.all = FALSE, Rupper.keep = FALSE)
conv.par(x, n.chains, Rupper.keep = TRUE)n * m * k array: m sequences of length n, k variables measuredk: "" if no transformation, or "log" or "logit"
(If trans is NULL, it will be set to "log" for parameters that
are all-positive and 0 otherwise.)FALSE (default), first half of a will be discardedFALSE, don't return Ruppermonitor:n.chains > 1,
"Rupper" if (Rupper.keep == TRUE) && (n.chains > 1), and "n.eff" if n.chains > 1conv.par a list with elements:m*n*min(sigma.hat^2/B,1).
This is a crude measure of sample size because it relies on the between
variance, B, which can only be estimated with m degrees of freedom.bugs.