Rdocumentation
powered by
Learn R Programming
R2WinBUGS (version 0.2-7)
write.datafile: Write data for WinBUGS - intended for internal use only
Description
Write data in files that can be read by WinBUGS - intended for internal use only
Usage
write.datafile(datalist, towhere, fill = TRUE) formatdata(datalist)
Arguments
datalist
a
list
to be written into an appropriate structure
towhere
the name of the file which the data are to be written to
fill
see
cat
, defaults to
TRUE
Value
datalist.tofile
A structure appropriate to be read in by WinBUGS.
See Also
The main function to be called by the user is
bugs
.