bugs.run: Calling WinBUGS - intended for internal use only
Description
Updates the lengths of the adaptive phases in the WinBUGS registry (using bugs.update.settings),
calls WinBUGS and runs it with script.txt. Intended for internal use only
Usage
bugs.run(n.burnin, bugs.directory)
Arguments
n.burnin
length of burn in
bugs.directory
directory that contains the WinBUGS executable
Value
Does not return anything.
See Also
The main function to be called by the user is bugs.